@@ -6,19 +6,6 @@
 # include <X11/Xft/Xft.h>
 #endif
 
-#ifdef HAVE_XSETLOCALE
-# define X_LOCALE
-# include <X11/Xlocale.h>
-#else
-# ifdef HAVE_SETLOCALE
-#  include <clocale>
-# endif
-#endif				/* HAVE_XLOCALE */
-
-#ifdef HAVE_NL_LANGINFO
-# include <langinfo.h>
-#endif
-
 #include <inttypes.h>
 
 #include "feature.h"
@@ -28,7 +15,8 @@
 
 struct rxvt_term;
 
-struct rxvt_fontprop {
+struct rxvt_fontprop
+{
   enum {
     unset  = -1,
     medium = 100, bold = 200,
@@ -38,20 +26,21 @@ struct rxvt_fontprop {
   int weight, slant;
 };
 
-struct rxvt_font {
+struct rxvt_font
+{
   // managed by the fontset
   rxvt_term *term;
   void set_term (rxvt_term *term) { this->term = term; }
 
   char *name;
   codeset cs;
-  bool loaded; // wether we tried loading it before (not wether it's loaded)
+  bool loaded; // whether we tried loading it before (not whether it's loaded)
 
   // managed by the font object
   int ascent, descent,
       width, height;
 
-  void set_name (char *name);
+  void set_name (char *name_);
 
   rxvt_font ();
   virtual ~rxvt_font () { free (name); };
@@ -69,28 +58,48 @@ struct rxvt_font {
                      int x, int y,
                      const text_t *text, int len,
                      int fg, int bg) = 0;
-};
 
-#define FONT_UNREF(f) do { (f)->clear (); delete (f); } while (0)
+  void unref ()
+  {
+    clear ();
+    delete this;
+  }
+};
 
 struct rxvt_fallback_font;
 
-struct rxvt_fontset {
+struct rxvt_fontset
+{
   char *fontdesc;
 
+  // must be power-of-two - 1, also has to match RS_fontMask in rxvt.h
+#if USE_256_COLORS
+  enum { fontCount =   7 }; // 4 extra colors bits, 4 fewer fontcount bits
+#else
+  enum { fontCount = 127 };
+#endif
+
+  // index of first font in set
+  enum { firstFont = 2 };
+
   rxvt_fontset (rxvt_term *term);
   ~rxvt_fontset ();
 
   bool populate (const char *desc);
   void set_prop (const rxvt_fontprop &prop, bool force_prop) { this->prop = prop; this->force_prop = force_prop; }
-  int find_font (uint32_t unicode);
+  int find_font_idx (uint32_t unicode);
   int find_font (const char *name) const;
   bool realize_font (int i);
 
-  // font-id's MUST fit into a signed 16 bit integer, and within 0..255
   rxvt_font *operator [] (int id) const
   {
-    return fonts[id & 0x7f];
+    return fonts[id >> 1];
+  }
+
+  int
+  find_font (unicode_t unicode)
+  {
+    return min<int> ((fontCount << 1) | 1, find_font_idx (unicode));
   }
 
 private:
@@ -105,7 +114,9 @@ private:
 
   void clear ();
   rxvt_font *new_font (const char *name, codeset cs);
+  void prepare_font (rxvt_font *font, codeset cs);
   void add_fonts (const char *desc);
+  void push_font (rxvt_font *font);
 };
 
 #endif /* _DEFAULTFONT_H_ */
